@@ -36,6 +36,26 @@
 #include <string.h>
 
 
+
+/* Property IDs */
+enum
+{
+  PROP_0,
+
+  PROP_TYPE,
+};
+
+static void		gconf_editor_window_set_property	(GObject          *object,
+								 guint             param_id,
+								 const GValue     *value,
+								 GParamSpec       *pspec);
+static void		gconf_editor_window_get_property	(GObject          *object,
+								 guint             param_id,
+								 GValue           *value,
+								 GParamSpec       *pspec);
+
+static GConfClient* 	gconf_editor_window_get_client 		(int type);
+
 static GObjectClass *parent_class;
 
 void
@@ -307,7 +327,7 @@ gconf_editor_window_new_window (GtkAction *action, GtkWidget *callback_data)
 {
 	GtkWidget *new_window;
 
-	new_window = gconf_editor_application_create_editor_window (GCONF_EDITOR_WINDOW_NORMAL);
+	new_window = gconf_editor_application_create_editor_window (GCONF_EDITOR_WINDOW_TYPE_NORMAL);
 	gtk_widget_show (new_window);
 }
 
@@ -316,7 +336,7 @@ gconf_editor_window_new_defaults_window (GtkAction *action, GtkWidget *callback_
 {
 	GtkWidget *new_window;
 
-	new_window = gconf_editor_application_create_editor_window (GCONF_EDITOR_WINDOW_DEFAULTS);
+	new_window = gconf_editor_application_create_editor_window (GCONF_EDITOR_WINDOW_TYPE_DEFAULTS);
 	gtk_widget_show (new_window);
 }
 
@@ -325,7 +345,7 @@ gconf_editor_window_new_mandatory_window (GtkAction *action, GtkWidget *callback
 {
 	GtkWidget *new_window;
 
-	new_window = gconf_editor_application_create_editor_window (GCONF_EDITOR_WINDOW_MANDATORY);
+	new_window = gconf_editor_application_create_editor_window (GCONF_EDITOR_WINDOW_TYPE_MANDATORY);
 	gtk_widget_show (new_window);
 }
 
@@ -338,7 +358,7 @@ help_cb (GtkAction *action, GtkWidget *callback_data)
                                                                                 
         if (error != NULL) {
                 gconf_editor_window_popup_error_dialog (GTK_WINDOW (GCONF_EDITOR_WINDOW (callback_data)),
-                                                        _("Couldn't display help: %s"), error);
+                                                        _("Couldn't display help: %s"), error->message);
         }
 }
 
@@ -362,8 +382,6 @@ gconf_editor_window_output_window_changed (GtkWidget *widget, gchar *key, gpoint
 static void
 gconf_editor_window_about_window (GtkAction *action, GtkWidget *callback_data)
 {
-	static GtkWidget *about;
-	GdkPixbuf *pixbuf = NULL;
 	const gchar *authors[] = {
 		"Anders Carlsson <andersca@gnome.org>",
 		"Fernando Herrera <fherrera@onirica.com>",
@@ -371,34 +389,20 @@ gconf_editor_window_about_window (GtkAction *action, GtkWidget *callback_data)
 	};
 	const gchar *documenters[] = {
 		"Sun Microsystems",
+		"Shaun McCance <shaunm@gnome.org>",
 		NULL
 	};
 	const gchar *translator_credits = _("translator_credits");
 
-	if (about != NULL) {
-		gtk_window_present (GTK_WINDOW (about));
-		return;
-	}
-
-	pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-					   "gconf-editor", 48, 0, NULL);
-
-	about = gnome_about_new (_("GConf-Editor"), VERSION,
-				 "Copyright \xc2\xa9 2001-2004 Anders Carlsson",
-				 _("An editor for the GConf configuration system."),
-				 authors,
-				 documenters,
-				 strcmp(translator_credits, "translator_credits") != 0 ?  translator_credits : NULL,
-				 pixbuf);
-	if (pixbuf != NULL)
-		gdk_pixbuf_unref (pixbuf);
-
-	g_signal_connect (G_OBJECT (about), "destroy",
-			 G_CALLBACK (gtk_widget_destroyed), &about);
-
-	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (callback_data));
-
-	gtk_widget_show (about);
+	gtk_show_about_dialog (GTK_WINDOW (callback_data),
+			      "version", VERSION,
+			      "copyright", "Copyright \xc2\xa9 2001-2004 Anders Carlsson",
+			      "comments", _("An editor for the GConf configuration system."),
+			      "authors", authors,
+			      "documenters", documenters,
+			      "translator_credits", strcmp(translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			      "logo_icon_name", "gconf-editor",
+			      NULL);
 }	
 
 static void
@@ -639,28 +643,17 @@ gconf_editor_popup_window_set_as_default (GtkAction *action, GtkWidget *callback
 {
   GConfEditorWindow *gconfwindow = GCONF_EDITOR_WINDOW (callback_data);
   GtkWindow *window = GTK_WINDOW (callback_data);
-  static GConfEngine *defaults_engine = NULL;
-  static GConfClient *defaults_client = NULL;
 
+  GConfClient *client;
   GError *error = NULL;
   GtkTreeIter iter;
   GConfValue *value;
   char *path = NULL;
   
-  if (defaults_engine == NULL) {
-    defaults_engine = gconf_engine_get_for_address (GCONF_DEFAULTS_SOURCE, &error);
-    if (error) {
-      gconf_editor_window_popup_error_dialog (window, _("Cannot create GConf engine. Error was:\n%s"), error);
-      return;
-    }
-  }
-  if (defaults_client == NULL) {
-    defaults_client = gconf_client_get_for_engine (defaults_engine);
-    if (defaults_client == NULL) {
-      /* TODO: error dialog */
-      g_print ("Could not create GConf client\n");
-      return;
-    }
+  client = gconf_editor_window_get_client (GCONF_EDITOR_WINDOW_TYPE_DEFAULTS);
+  if (client == NULL) {
+    g_print ("Could not create GConf client\n");
+    return;
   }
 	
   gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (gconfwindow->list_view)),
@@ -670,13 +663,13 @@ gconf_editor_popup_window_set_as_default (GtkAction *action, GtkWidget *callback
                       GCONF_LIST_MODEL_VALUE_COLUMN, &value,
                       -1);
 
-  gconf_client_set (defaults_client, path, value, NULL);
+  gconf_client_set (client, path, value, NULL);
 
-  gconf_client_suggest_sync (defaults_client, &error);
+  gconf_client_suggest_sync (client, &error);
   if (error) {
     gconf_editor_window_popup_error_dialog (window, _("Could not sync value. Error was:\n%s"), error);
-    return;
   }
+  g_object_unref (client);
 }
 
 static void
@@ -684,28 +677,18 @@ gconf_editor_popup_window_set_as_mandatory (GtkAction *action, GtkWidget *callba
 {
   GConfEditorWindow *gconfwindow = GCONF_EDITOR_WINDOW (callback_data);
   GtkWindow *window = GTK_WINDOW (callback_data);
-  static GConfEngine *defaults_engine = NULL;
-  static GConfClient *defaults_client = NULL;
 
   GError *error = NULL;
   GtkTreeIter iter;
   GConfValue *value;
   char *path = NULL;
+  GConfClient *client;
   
-  if (defaults_engine == NULL) {
-    defaults_engine = gconf_engine_get_for_address (GCONF_MANDATORY_SOURCE, &error);
-    if (error) {
-      gconf_editor_window_popup_error_dialog (window, _("Cannot create GConf engine. Error was:\n%s"), error);
-      return;
-    }
-  }
-  if (defaults_client == NULL) {
-    defaults_client = gconf_client_get_for_engine (defaults_engine);
-    if (defaults_client == NULL) {
-      /* TODO: error dialog */
-      g_print ("Could not create GConf client\n");
-      return;
-    }
+
+  client = gconf_editor_window_get_client (GCONF_EDITOR_WINDOW_TYPE_MANDATORY);
+  if (client == NULL) {
+    g_print ("Could not create GConf client\n");
+    return;
   }
 	
   gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (gconfwindow->list_view)),
@@ -715,13 +698,13 @@ gconf_editor_popup_window_set_as_mandatory (GtkAction *action, GtkWidget *callba
                       GCONF_LIST_MODEL_VALUE_COLUMN, &value,
                       -1);
 
-  gconf_client_set (defaults_client, path, value, NULL);
+  gconf_client_set (client, path, value, NULL);
 
-  gconf_client_suggest_sync (defaults_client, &error);
+  gconf_client_suggest_sync (client, &error);
   if (error) {
     gconf_editor_window_popup_error_dialog (window, _("Could not sync value. Error was:\n%s"), error);
-    return;
   }
+  g_object_unref (client);
 }
 
 static GtkActionEntry entries[] = {
@@ -732,17 +715,17 @@ static GtkActionEntry entries[] = {
 	{ "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
 
 	{ "NewWindow", GTK_STOCK_NEW, N_("New _Settings Window"), "<control>S", 
-	  N_("Open a new gconf editor window editing current settings"), 
+	  N_("Open a new Configuration Editor window editing current settings"), 
 	  G_CALLBACK (gconf_editor_window_new_window) },
 	{ "NewDefaultsWindow", GTK_STOCK_NEW, N_("New _Defaults Window"), "<control>D", 
-          N_("Open a new gconf editor window editing system default settings"), 
+          N_("Open a new Configuration Editor window editing system default settings"), 
 	  G_CALLBACK (gconf_editor_window_new_defaults_window) },
 	{ "NewMandatoryWindow", GTK_STOCK_NEW, N_("New _Mandatory Window"), "<control>M", 
-          N_("Open a new gconf editor window editing system mandatory settings"), 
+          N_("Open a new Configuration Editor window editing system mandatory settings"), 
 	  G_CALLBACK (gconf_editor_window_new_mandatory_window) },
 	{ "CloseWindow", GTK_STOCK_CLOSE, N_("_Close Window"), "<control>W", N_("Close this window"), 
 	  G_CALLBACK (gconf_editor_window_close_window) },
-	{ "QuitGConfEditor", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q", N_("Quit the gconf editor"), 
+	{ "QuitGConfEditor", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q", N_("Quit the Configuration Editor"), 
 	  G_CALLBACK (gtk_main_quit) },
 	
 	{ "CopyKeyName", GTK_STOCK_COPY, N_("_Copy Key Name"), "<control>C", N_("Copy the name of the selected key"), 
@@ -752,14 +735,14 @@ static GtkActionEntry entries[] = {
 	{ "RecentKeys", NULL, N_("_List Recent Keys"), "<control>R", N_("Show recently modified keys"), 
 	  G_CALLBACK (gconf_editor_show_recent_keys) },
 
-	{ "AddBookmark", GTK_STOCK_ADD, N_("_Add Bookmark"), NULL, N_("Add a bookmark to the selected directory"), 
+	{ "AddBookmark", STOCK_ADD_BOOKMARK, N_("_Add Bookmark"), NULL, N_("Add a bookmark to the selected directory"), 
 	  G_CALLBACK (gconf_editor_window_add_bookmark) },
-	{ "EditBookmarks", NULL, N_("_Edit Bookmarks"), NULL, N_("Edit the bookmarks"), 
+	{ "EditBookmarks", STOCK_EDIT_BOOKMARK, N_("_Edit Bookmarks"), NULL, N_("Edit the bookmarks"), 
 	G_CALLBACK (gconf_editor_window_edit_bookmarks) },
 	
-	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1", N_("Open the help contents for the gconf editor"), 
+	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1", N_("Open the help contents for the Configuration Editor"), 
 	  G_CALLBACK (help_cb) },
-	{ "AboutAction", GNOME_STOCK_ABOUT, N_("_About"), NULL, N_("Show the about dialog for the gconf editor"), 
+	{ "AboutAction", GNOME_STOCK_ABOUT, N_("_About"), NULL, N_("Show the about dialog for the Configuration Editor"), 
 	  G_CALLBACK (gconf_editor_window_about_window) },
 
 	{ "NewKey", GTK_STOCK_NEW, N_("_New Key..."), "<control>N", N_("Create a new key"),
@@ -831,13 +814,6 @@ static gchar *image_menu_items_paths[] = {
 	"/GConfKeyPopupMenu/UnsetKey"
 };
 
-static gchar *tearoff_paths[] = {
-	"/GConfEditorMenu/FileMenu",
-	"/GConfEditorMenu/EditMenu",
-	"/GConfEditorMenu/BookmarksMenu",
-	"/GConfEditorMenu/HelpMenu"
-};
-
 static void
 gconf_editor_window_row_activated (GtkTreeView *treeview, 
 				   GtkTreePath *path,
@@ -855,16 +831,27 @@ static void
 gconf_editor_window_selection_changed (GtkTreeSelection *selection, GConfEditorWindow *window)
 {
 	GtkTreeIter iter;
-	
+	gchar *base_title;
+
+	switch (window->type) {
+	case GCONF_EDITOR_WINDOW_TYPE_DEFAULTS:
+		base_title = _("Configuration Editor (Default Settings)");
+		break;
+	case GCONF_EDITOR_WINDOW_TYPE_MANDATORY:
+		base_title = _("Configuration Editor (Mandatory Settings)");
+		break;
+	default:
+		base_title = _("Configuration Editor");
+	}
+		
 	if (selection == NULL)
-		gtk_window_set_title (GTK_WINDOW (window), _("GConf editor"));
+		gtk_window_set_title (GTK_WINDOW (window), base_title);
 	else {
 		gchar *name, *title, *path;
 		GtkTreeIter child_iter;
 
 		if (!gtk_tree_selection_get_selected (selection, NULL, &iter)) {
-			gtk_window_set_title (GTK_WINDOW (window),
-					      _("GConf editor"));
+			gtk_window_set_title (GTK_WINDOW (window), base_title);
 			return;
 		}
 
@@ -872,7 +859,12 @@ gconf_editor_window_selection_changed (GtkTreeSelection *selection, GConfEditorW
 
 		name = gconf_tree_model_get_gconf_name (GCONF_TREE_MODEL (window->tree_model), &child_iter);
 
-		title = g_strdup_printf (_("GConf editor - %s"), name);
+		if (strlen (name) > 0) {
+			title = g_strdup_printf ("%s - %s", base_title, name);
+		}
+		else {
+			title = g_strdup (base_title);
+		}
 		
 		gtk_window_set_title (GTK_WINDOW (window), title);
 		g_free (title);
@@ -885,7 +877,6 @@ gconf_editor_window_selection_changed (GtkTreeSelection *selection, GConfEditorW
 		gconf_list_model_set_root_path (GCONF_LIST_MODEL (window->list_model), path);
 
 		g_free (path);
-
 	}
 }
 
@@ -1109,51 +1100,29 @@ gconf_editor_window_update_list_selection (GtkTreeSelection *selection, GConfEdi
 
 	if (schema == NULL) {
 		GConfValue *value = gconf_client_get (window->client, path, NULL);
-		if (value->type == GCONF_VALUE_SCHEMA) {
-			gtk_widget_hide (window->no_schema_label);
+		if (value != NULL) {
+			if (value->type == GCONF_VALUE_SCHEMA) {
+				gtk_widget_hide (window->no_schema_label);
+			}
+			else {
+				gtk_widget_show (window->no_schema_label);
+			}
+			gconf_value_free (value);
 		}
-		else {
-			gtk_widget_show (window->no_schema_label);
-		}
-		gconf_value_free (value);
 	}
 	else {
 		gtk_widget_hide (window->no_schema_label);
 	}
 
+	if (schema != NULL)
+		gconf_schema_free (schema);
+
 	gtk_statusbar_pop (GTK_STATUSBAR (window->statusbar), 0);
 	gtk_statusbar_push (GTK_STATUSBAR (window->statusbar), 0, path);
 
 	g_free (path);
 }
 
-static void
-gconf_editor_window_set_have_tearoffs (GConfEditorWindow *window,
-				       gboolean           have_tearoffs)
-{
-	int i;
-
-	for (i = 0; i < G_N_ELEMENTS (tearoff_paths); i++) {
-		GtkWidget *menu;
-		GtkWidget *item;
-		GList *list;
-
-		item = gtk_ui_manager_get_widget (window->ui_manager, tearoff_paths [i]);
-
-		menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (item));
-		list = gtk_container_get_children (GTK_CONTAINER (menu));
-
-		item = GTK_WIDGET (list->data); 
-		
-		g_list_free (list);
-
-		if (have_tearoffs)
-			gtk_widget_show (item);
-		else
-			gtk_widget_hide (item);
-	}
-}
-
 static void
 gconf_editor_window_have_tearoffs_notify (GConfClient       *client,
 					  guint              cnxn_id,
@@ -1167,7 +1136,7 @@ gconf_editor_window_have_tearoffs_notify (GConfClient       *client,
 
 	have_tearoffs = gconf_value_get_bool (entry->value);
 
-	gconf_editor_window_set_have_tearoffs (window, have_tearoffs);
+	gtk_ui_manager_set_add_tearoffs (window->ui_manager, have_tearoffs);
 }
 
 static void
@@ -1230,8 +1199,9 @@ gconf_editor_window_setup_ui_prefs_handler (GConfEditorWindow *window)
 
 	client = gconf_client_get_default ();
 
-	gconf_editor_window_set_have_tearoffs (
-		window, gconf_client_get_bool (client, "/desktop/gnome/interface/menus_have_tearoff", NULL));
+	gtk_ui_manager_set_add_tearoffs (
+		window->ui_manager, gconf_client_get_bool (client, "/desktop/gnome/interface/menus_have_tearoff", 
+							   NULL));
 
 	window->tearoffs_notify_id = gconf_client_notify_add (
 						client,
@@ -1268,6 +1238,105 @@ gconf_editor_window_expand_first (GConfEditorWindow *window)
 	gtk_tree_path_free (path);
 }
 
+static GConfClient*
+gconf_editor_window_get_client (int type)
+{
+	static GConfClient *defaults_client = NULL;
+	static GConfClient *mandatory_client = NULL;
+
+	GConfEngine *engine;
+	GConfClient *client = NULL;
+        GError *error = NULL;
+
+	switch (type) {
+	case GCONF_EDITOR_WINDOW_TYPE_NORMAL:
+		client = gconf_client_get_default ();
+		break;
+	case GCONF_EDITOR_WINDOW_TYPE_DEFAULTS:
+		if (defaults_client != NULL) {
+			client = defaults_client;
+			g_object_ref (defaults_client);
+		} else {
+			engine = gconf_engine_get_for_address (GCONF_DEFAULTS_SOURCE, &error);
+			if (error) {
+				gconf_editor_window_popup_error_dialog (NULL,
+				_("Cannot create GConf engine. Error was:\n%s"), error);
+				return NULL;
+			}
+			client = gconf_client_get_for_engine (engine);
+			gconf_engine_unref (engine);
+		}
+		break;
+	case GCONF_EDITOR_WINDOW_TYPE_MANDATORY:
+		if (mandatory_client != NULL) {
+			client = mandatory_client;
+			g_object_ref (mandatory_client);
+		} else {
+			engine = gconf_engine_get_for_address (GCONF_MANDATORY_SOURCE, &error);
+			if (error) {
+				gconf_editor_window_popup_error_dialog (NULL,
+				_("Cannot create GConf engine. Error was:\n%s"), error);
+				return NULL;
+			}
+			client = gconf_client_get_for_engine (engine);
+			gconf_engine_unref (engine);
+		}
+		break;
+	default:
+		g_assert_not_reached ();
+	}
+
+	return client;
+}
+
+static void
+gconf_editor_window_set_property (GObject      *object,
+				  guint         param_id,
+				  const GValue *value,
+				  GParamSpec   *pspec)
+{
+	GConfEditorWindow *gconfwindow = (GConfEditorWindow *) object;
+
+	switch (param_id) {
+	case PROP_TYPE:
+		/* Construct-only */
+		gconfwindow->type = g_value_get_int (value);
+		gconfwindow->client = gconf_editor_window_get_client (gconfwindow->type);
+		switch (gconfwindow->type) {
+			case GCONF_EDITOR_WINDOW_TYPE_DEFAULTS:
+				gtk_window_set_title (GTK_WINDOW (gconfwindow), _("Configuration Editor (Defaults settings)"));
+				break;
+			case GCONF_EDITOR_WINDOW_TYPE_MANDATORY:
+				gtk_window_set_title (GTK_WINDOW (gconfwindow), _("Configuration Editor (Mandatory settings)"));
+				break;
+			default:
+				gtk_window_set_title (GTK_WINDOW (gconfwindow), _("Configuration Editor"));
+			}
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
+}
+
+static void
+gconf_editor_window_get_property (GObject      *object,
+				  guint         param_id,
+				  GValue       *value,
+				  GParamSpec   *pspec)
+{
+
+	GConfEditorWindow *gconfwindow = (GConfEditorWindow *) object;
+
+	switch (param_id) {
+	case PROP_TYPE:
+		g_value_set_int (value, gconfwindow->type);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
+}
 
 static void
 gconf_editor_window_finalize (GObject *object)
@@ -1297,16 +1366,29 @@ gconf_editor_window_class_init (GConfEditorWindowClass *klass)
 {
 	GObjectClass *object_class = (GObjectClass *) klass;
 
+	object_class->set_property = gconf_editor_window_set_property;
+	object_class->get_property = gconf_editor_window_get_property;
 	object_class->finalize = gconf_editor_window_finalize;
 
+	g_object_class_install_property (object_class, PROP_TYPE,
+					 g_param_spec_int ("type",
+					 _("Type"),
+					 _("The Configuration Editor window type."),
+					 GCONF_EDITOR_WINDOW_TYPE_NORMAL, GCONF_EDITOR_WINDOW_TYPE_MANDATORY,
+					 GCONF_EDITOR_WINDOW_TYPE_NORMAL, 
+					 (G_PARAM_WRITABLE |
+					 G_PARAM_CONSTRUCT_ONLY)));
+
+
 	parent_class = g_type_class_peek_parent (klass);
 }
 
+
+
 static void
 gconf_editor_window_init (GConfEditorWindow *window)
 {
 	GtkWidget *hpaned, *vpaned, *scrolled_window, *vbox;
-	GdkPixbuf *icon;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell;
 	GtkAccelGroup *accel_group;
@@ -1316,7 +1398,6 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	gchar *markup;
 	GError *error;
 	
-	gtk_window_set_title (GTK_WINDOW (window), _("GConf editor"));
 	gtk_window_set_default_size (GTK_WINDOW (window), 700, 550);
 
 	vbox = gtk_vbox_new (FALSE, 0);
@@ -1345,19 +1426,6 @@ gconf_editor_window_init (GConfEditorWindow *window)
 
 	window->popup_menu = gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu");
 
-	if (!gconf_client_can_edit_defaults ()) {
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/DefaultKey"),
-					  FALSE);
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfEditorMenu/FileMenu/NewDefaultsWindow"),
-					  FALSE);
-	}
-	if (!gconf_client_can_edit_mandatory ()) {
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfKeyPopupMenu/MandatoryKey"),
-					  FALSE);
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (window->ui_manager, "/GConfEditorMenu/FileMenu/NewMandatoryWindow"),
-					  FALSE);
-	}
-
 	/* Hook up bookmarks */
 	gconf_bookmarks_hook_up_menu (window,
 				      gtk_menu_item_get_submenu (GTK_MENU_ITEM (gtk_ui_manager_get_widget (window->ui_manager,
@@ -1522,8 +1590,8 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	gtk_container_add (GTK_CONTAINER (details_frame), alignment);
 
 	table = gtk_table_new (6, 2, FALSE);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 6);
 	
 	gtk_container_add (GTK_CONTAINER (alignment), table);
 
@@ -1555,8 +1623,8 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	gtk_box_pack_start (GTK_BOX (window->no_schema_label), label, FALSE, FALSE, 0);
 
 
-	label = gtk_label_new (_("Key Name:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+	label = gtk_label_new (_("Key name:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1, 2, 3,
@@ -1568,8 +1636,8 @@ gconf_editor_window_init (GConfEditorWindow *window)
 			  1, 2, 2, 3,
 			  GTK_FILL, 0, 0, 0);
 	
-	label = gtk_label_new (_("Key Owner:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);	
+	label = gtk_label_new (_("Key owner:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);	
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1, 3, 4,
 			  GTK_FILL, 0, 0, 0);
@@ -1580,8 +1648,8 @@ gconf_editor_window_init (GConfEditorWindow *window)
 			  1, 2, 3, 4,
 			  GTK_FILL, 0, 0, 0);
 
-	label = gtk_label_new (_("Short Description:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);	
+	label = gtk_label_new (_("Short description:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);	
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1, 4, 5,
 			  GTK_FILL, 0, 0, 0);
@@ -1593,8 +1661,8 @@ gconf_editor_window_init (GConfEditorWindow *window)
 			  1, 2, 4, 5,
 			  GTK_FILL, 0, 0, 0);
 
-	label = gtk_label_new (_("Long Description:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.0);	
+	label = gtk_label_new (_("Long description:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);	
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1, 5, 6,
 			  GTK_FILL, GTK_FILL, 0, 0);
@@ -1622,12 +1690,7 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	gtk_widget_hide (window->no_schema_label);
 	gtk_widget_hide (window->output_window);
 	
-	/* Set window icon */
-	icon = gdk_pixbuf_new_from_file (IMAGEDIR"/gconf-editor.png", NULL);
-	if (icon != NULL) {
-		gtk_window_set_icon (GTK_WINDOW (window), icon);
-		g_object_unref (icon);
-	}
+	gtk_window_set_default_icon_name ("gconf-editor");
 
 	gconf_editor_window_setup_ui_prefs_handler (window);
 }
